var webpack = require('webpack')
var path = require('path')
var HtmlWebpackPlugin = require('html-webpack-plugin');
var ExtractTextPlugin = require('extract-text-webpack-plugin');

module.exports = {
    entry: {
        global : path.resolve(__dirname, '../src/global.js'),
        index : ['babel-polyfill', path.resolve(__dirname, '../src/index.js')]
    },
    output: {
        path: path.resolve(__dirname, '../dist'),
        filename: '[name].[hash:8].bundle.js'
    },
    plugins: [
        new HtmlWebpackPlugin({
            template: path.resolve(__dirname, '../src/index.html'),
            filename: 'index.html',
            inject: true
        }),
        new webpack.ProvidePlugin({
            'Promise':'es6-promise',
            'fetch': 'imports-loader?this=>global!exports-loader?global.fetch!whatwg-fetch'
        }),
        new ExtractTextPlugin('./[name].[hash:8].css'),
        new webpack.optimize.CommonsChunkPlugin({
            name: 'global'
        })
    ],

    module: {
        rules: [{
            test: /\.js$/,
            exclude: /node_modules\\(?!allsome\-[0-9a-zA-Z\-]+)/,
            loader: "babel-loader",
            options: {
                presets: ["env", "react", "stage-3"]
            }
        }, 
        {
            test: /\.less$/,
            use: ExtractTextPlugin.extract({
                fallback: 'style-loader',
                use: [
                    {
                        loader: 'css-loader' ,
                        options: { 
                            modules: true,
                            minimize : true
                        }
                    },
                    {
                        loader: 'postcss-loader',
                        options: {
                            plugins: loader => [
                                require('autoprefixer')({ browsers: ['last 2 versions', 'iOS >= 8'] }),
                            ]
                        }
                    },
                    { loader: 'less-loader' }
                ]
            })
        },
        {
            test: /\.(gif|jpg|png|woff|eot|ttf)$/,
            use: [
                {
                    loader: 'url-loader',
                    options: {
                        limit:8192 // 图片小于8k就转化为 base64, 或者单独作为文件
                    }
                }
            ]
        },
        {
            test: /\.svg/,
            use: [{
                loader: "svg-url-loader",
                options: {
                    dataUrlLimit: 1024
                }
            }]
        }]
    },
    resolve: {

		alias: {
			'global': path.resolve(__dirname, '../src/global')
		}
	}


}